@@ -1329,8 +1329,8 @@ def parseCaseInfo(conf):
             b['DispositionCharges'] = b['AllPagesText'].map(lambda x: getDispositionCharges(x))
             b['FilingCharges'] = b['AllPagesText'].map(lambda x: getFilingCharges(x))
             b['CERVConvictions'] = b['AllPagesText'].map(lambda x: getCERVConvictions(x))
-            b['PardonDQConvictions'] = b['AllPagesText'].map(lambda x: getPardonConvictions(x))
-            b['PermanentDQConvictions'] = b['AllPagesText'].map(lambda x: getPermanentConvictions(x))
+            b['PardonDQConvictions'] = b['AllPagesText'].map(lambda x: getPardonDQConvictions(x))
+            b['PermanentDQConvictions'] = b['AllPagesText'].map(lambda x: getPermanentDQConvictions(x))
             b['Phone'] =  b['Phone'].map(lambda x: pd.to_numeric(x,'coerce'))
             b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
             b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x,'coerce'))
